# \donttest{
## Load datasets of network meta-analysis of
## chronic obstructive pulmonary disease (COPD)
data(dat.copd)
## Assess fragility of network meta-analysis of COPD
out1 <- frag.nma(sid, tid, e, n, data = dat.copd)
out1
## Retrieve the estimated log odds ratio in the original dataset
out1$est.ori
## Retrieve the fragility index of each treatment comparison
out1$FI
## Retrieve the direction of significance change for comparison 2 vs. 3
out1$dir["2", "3"]
## Retrieve the study IDs with iterative event status modifications
## for comparison 2 vs. 3
out1$sid.iter[["2 vs. 3"]]
## Retrieve the event status modifications
## in the first group (i.e., treatment 2)
out1$tid1.mod.iter[["2 vs. 3"]]
## Retrieve the event status modifications
## in the second group (i.e., treatment 3)
out1$tid2.mod.iter[["2 vs. 3"]]
## Visualize the process of event status modifications
## for altering the non-significance to significance for each comparison;
## see more options of usage in examples of frag.ma()
plot(out1, tid1 = 2, tid2 = 1)
plot(out1, tid1 = 3, tid2 = 1)
plot(out1, tid1 = 4, tid2 = 1)
plot(out1, tid1 = 3, tid2 = 2)
plot(out1, tid1 = 4, tid2 = 2)
plot(out1, tid1 = 4, tid2 = 3)
## Assess fragility of treatment comparisons 2 vs. 1 and 3 vs. 1 only
out2 <- frag.nma(sid, tid, e, n, data = dat.copd,
tid1.f = c(2, 3), tid2.f = c(1, 1))
out2
## The default plot presents the process of event status modification
## for the first comparison, i.e., 2 vs. 1
plot(out2)
## Load datasets of network meta-analysis of smoking cessation
data(dat.sc)
## Assess fragility of network meta-analysis of smoking cessation
out3 <- frag.nma(sid, tid, e, n, data = dat.sc)
out3
## Visualize the process of event status modifications
plot(out3, tid1 = 2, tid2 = 1, ybreaks = c(170, 595),
x.legend = "topright")
plot(out3, tid1 = 3, tid2 = 1, ybreaks = c(635, 1200),
x.legend = "bottomright")
plot(out3, tid1 = 4, tid2 = 1, ybreaks = c(105, 600))
plot(out3, tid1 = 3, tid2 = 2, ybreaks = c(160, 1205))
plot(out3, tid1 = 4, tid2 = 2, ybreaks = c(110, 140),
x.legend = "topright")
plot(out3, tid1 = 4, tid2 = 3, ybreaks = c(130, 1205),
x.legend = "bottomright")
# }
Run the code above in your browser using DataLab