Prints information about the fragility of a meta-analysis with a binary outcome.
# S3 method for frag.ma
print(x, ...)None.
an object of class "frag.ma" produced by the function frag.ma.
other arguments.
The output includes the characteristics of the meta-analysis (the number of studies, events, and samples), the estimated overall effect size, the information about significance (the pre-specified significance level, the null value, the confidence interval, and the p-value), and the fragility index and quotient.
frag.ma