Prints information about the fragility of a meta-analysis with a binary outcome at different statistical significance levels.
# S3 method for frag.ma.alpha
print(x, ...)None.
an object of class "frag.ma.alpha" produced by the function frag.ma.alpha.
other arguments.
The output includes the characteristics of the meta-analysis (the number of studies, events, and samples), the estimated overall effect size, the information about significance (the range of considered significance levels, the null value, and the p-value), and the averages, minimums, and maximums of fragility index and fragility quotient across different statistical significance levels.
frag.ma.alpha