Learn R Programming

fragility (version 1.6.1)

print.frag.mas: Print Method for "frag.mas" Objects

Description

Prints information about the fragility of multiple meta-analyses with binary outcomes.

Usage

# S3 method for frag.mas
print(x, ...)

Value

None.

Arguments

x

an object of class "frag.mas" produced by the function frag.mas.

...

other arguments.

Details

The output includes the number of meta-analyses, the pre-specified significance level, the null value of effect size, and the descriptive information about the fragility of the multiple meta-analyses, such as the median, range (from minimum to maximum), and interquartile range (IQR, from the first quartile to the third quartile) of fragility index and those of fragility quotient.

See Also

frag.mas