Prints information about the fragility of a network meta-analysis with a binary outcome.
# S3 method for frag.nma
print(x, ...)None.
an object of class "frag.nma" produced by the function frag.nma.
other arguments.
Due to the space limit, the output only includes the basic characteristics of the network meta-analysis (the numbers of studies and treatments), the effect size, and the brief information about fragility index and quotient. More information can be retrieved from the list object x. For example, the estimated effect sizes can be retrieved from x$est.ori, and the directions of significance change corresponding to the fragility index/quotient can be retrieved from x$dir.
frag.nma