Learn R Programming

fragility (version 1.6.1)

print.frag.study: Print Method for "frag.study" Objects

Description

Prints information about the fragility of an individual study with a binary outcome.

Usage

# S3 method for frag.study
print(x, ...)

Value

None.

Arguments

x

an object of class "frag.study" produced by the function frag.study.

...

other arguments.

Details

The output consists of three parts: 1) the information about the original data, where the 2\(\times\)2 table and the ranges of event status modifications in both groups are presented; 2) the information about the significance, including the pre-specified significance level, null value(s) (if the odds ratio, relative risk, and/or risk difference are used), and the p-value(s) with the associated method and the alternative hypothesis; and 3) the information about the fragility, including the fragility index and fragility quotient based on each method considered, the direction of significance change, and the corresponding minimal event status modification(s) for altering significance or non-significance. If both groups have no event status modifications, the third part will not be printed because the fragility needs to be assessed based on certain event status modifications.

See Also

frag.study