Prints information about the fragility of an individual study with a binary outcome at different statistical significance levels.
# S3 method for frag.study.alpha
print(x, ...)None.
an object of class "frag.study.alpha" produced by the function frag.study.alpha.
other arguments.
The output consists of three parts: 1) the information about the original data, where the 2\(\times\)2 table and the ranges of event status modifications in both groups are presented; 2) the information about the significance, including the pre-specified significance level, null value(s) (if the odds ratio, relative risk, and/or risk difference are used), and the p-value(s) with the associated method and the alternative hypothesis; and 3) the information about the fragility, including the averages, minimums, and maximums of fragility index and fragility quotient based on each method considered across different statistical significance levels. If both groups have no event status modifications, the third part will not be printed because the fragility needs to be assessed based on certain event status modifications.
frag.study.alpha